@@ -35,8 +35,6 @@
 use diagnostics;
 use strict;
 
-my $var_lib='/var/lib/bugzilla';
-
 # Shut up misguided -w warnings about "used only once".  For some reason,
 # "use vars" chokes on me when I try it here.
 
@@ -59,7 +57,7 @@ sub WriteParams {
 
     require File::Temp;
     my ($fh, $tmpname) = File::Temp::tempfile("params.XXXXX",
-                                              DIR=>"$var_lib/data");
+                                              DIR=>'data');
     my $v = $::param{'version'};
     delete $::param{'version'};  # Don't write the version number out to
                                 # the params file.
@@ -67,8 +65,8 @@ sub WriteParams {
     $::param{'version'} = $v;
     print $fh "1;\n";
     close $fh;
-    rename $tmpname, "$var_lib/data/params" || die "Can't rename $tmpname to $var_lib/data/params";
-    ChmodDataFile("$var_lib/data/params", 0644);
+    rename $tmpname, "data/params" || die "Can't rename $tmpname to data/params";
+    ChmodDataFile('data/params', 0666);
 }
     
 
@@ -137,7 +135,7 @@ DefParam("maintainer",
 DefParam("urlbase",
          "The URL that is the common initial leading part of all Bugzilla URLs.",
          "t",
-         "http://localhost/cgi-bin/bugzilla/",
+         "http://cvs-mirror.mozilla.org/webtools/bugzilla/",
          \&check_urlbase);
 
 sub check_urlbase {
@@ -230,7 +228,7 @@ DefParam("shutdownhtml",
          "");
 
 DefParam("sendmailnow",
-         "If this is on, Bugzilla will tell sendmail to send any e-mail immediately. If you have a large number of users with a large amount of e-mail traffic, enabling this option may dramatically slow down Bugzilla. Best used for smaller installations of Bugzilla.",
+         "Sites using anything older than version 8.12 of \'sendmail\' can achieve a significant performance increase in the UI -- at the cost of delaying the sending of mail -- by disabling this parameter. Sites using 'sendmail' 8.12 or higher should leave this on, as they will see no benefit from turning it off. Sites using an MTA other than 'sendmail' *must* leave it on, or no bug mail will be sent.",
          "b",
          1);
 
@@ -337,7 +335,7 @@ You will get this message once a day until you've dealt with these bugs!
 
 
 DefParam("defaultquery",
-          "This is the default query that initially comes up when you submit a bug.  It's in URL parameter format, which makes it hard to read.  Sorry!",
+          "This is the default query that initially comes up when you access the query page.  It's in URL parameter format, which makes it hard to read.  Sorry!",
          "t",
          "bug_status=NEW&bug_status=ASSIGNED&bug_status=REOPENED&emailassigned_to1=1&emailassigned_to2=1&emailreporter2=1&emailcc2=1&emailqa_contact2=1&order=%22Importance%22");
 
@@ -446,7 +444,7 @@ sub check_webdotbase {
             return "The file path \"$value\" is not a valid executable.  Please specify the complete file path to 'dot' if you intend to generate graphs locally.";
         }
         # Check .htaccess allows access to generated images
-        if(-e "$var_lib/data/webdot/.htaccess") {
+        if(-e "data/webdot/.htaccess") {
             open HTACCESS, "data/webdot/.htaccess";
             if(! grep(/ \\\.png\$/,<HTACCESS>)) {
                 print "Dependency graph images are not accessible.\nAssuming that you have not modified the file, delete data/webdot/.htaccess and re-run checksetup.pl to rectify.\n";
@@ -456,6 +454,7 @@ sub check_webdotbase {
     }
     return "";
 }
+
 DefParam("expectbigqueries",
          "If this is on, then we will tell mysql to <tt>set option SQL_BIG_TABLES=1</tt> before doing queries on bugs.  This will be a little slower, but one will not get the error <tt>The table ### is full</tt> for big queries that require a big temporary table.",
          "b",
