@@ -28,14 +28,6 @@
 use diagnostics;
 use strict;
 
-use lib '/usr/share/bugzilla/lib';
-
-my $var_lib="/var/lib/bugzilla";
-my $lib_dir="/usr/share/bugzilla/lib";
-my $template_dir="/usr/share/bugzilla/template";
-my $custom_template_dir="/var/lib/bugzilla/template";
-my $cache_dir="/var/cache/bugzilla";
-
 # Shut up misguided -w warnings about "used only once".  For some reason,
 # "use vars" chokes on me when I try it here.
 
@@ -79,7 +71,7 @@ $::db_name = "bugs";
 $::db_user = "bugs";
 $::db_pass = "";
 
-do '/etc/bugzilla/localconfig';
+do 'localconfig';
 
 use DBI;
 
@@ -106,7 +98,7 @@ $::SIG{TERM} = 'IGNORE';
 $::SIG{PIPE} = 'IGNORE';
 
 # Contains the version string for the current running Bugzilla.
-$::param{'version'} = '2.16.7';
+$::param{'version'} = '2.16.8';
 
 $::dontchange = "--do_not_change--";
 $::chooseone = "--Choose_one:--";
@@ -130,7 +122,7 @@ $::superusergroupset = "9223372036854775807";
 sub ChmodDataFile($$) {
     my ($file, $mask) = @_;
     my $perm = 0770;
-    if ((stat("$var_lib/data"))[2] & 0002) {
+    if ((stat('data'))[2] & 0002) {
         $perm = 0777;
     }
     $perm = $perm & $mask;
@@ -173,7 +165,7 @@ sub SyncAnyPendingShadowChanges {
                 my $redir = ($^O =~ /MSWin32/i) ? "NUL" : "/dev/null";
                 open STDOUT,">$redir";
                 open STDERR,">$redir";
-                exec("/usr/share/bugzilla/lib/syncshadowdb","--") or die "Unable to exec syncshadowdb: $!";
+                exec("./syncshadowdb","--") or die "Unable to exec syncshadowdb: $!";
                 # the idea was that passing the second parameter tricks it into
                 # using execvp instead of running a shell. Not really necessary since
                 # there are no shell meta-characters, but it passes our tinderbox
@@ -215,12 +207,12 @@ sub SavedSQLStates() {
 }
 
 
-my $dosqllog = (-e "$var_lib/data/sqllog") && (-w "$var_lib/data/sqllog");
+my $dosqllog = (-e "data/sqllog") && (-w "data/sqllog");
 
 sub SqlLog {
     if ($dosqllog) {
         my ($str) = (@_);
-        open(SQLLOGFID, ">>$var_lib/data/sqllog") || die "Can't write to $var_lib/data/sqllog";
+        open(SQLLOGFID, ">>data/sqllog") || die "Can't write to data/sqllog";
         if (flock(SQLLOGFID,2)) { # 2 is magic 'exclusive lock' const.
 
             # if we're a subquery (ie there's pushed global state around)
@@ -527,7 +519,7 @@ sub GenerateVersionTable {
     @::legal_product = @list;
     require File::Temp;
     my ($fh, $tmpname) = File::Temp::tempfile("versioncache.XXXXX",
-                                              DIR=>"$var_lib/data");
+                                              DIR=>'data');
 
     print $fh "#\n";
     print $fh "# DO NOT EDIT!\n";
@@ -593,8 +585,8 @@ sub GenerateVersionTable {
 
     print $fh "1;\n";
     close $fh;
-    rename $tmpname, "$var_lib/data/versioncache" || die "Can't rename $tmpname to versioncache";
-    ChmodDataFile("$var_lib/data/versioncache", 0644);
+    rename $tmpname, "data/versioncache" || die "Can't rename $tmpname to versioncache";
+    ChmodDataFile('data/versioncache', 0666);
 }
 
 
@@ -624,8 +616,8 @@ sub ModTime {
 $::VersionTableLoaded = 0;
 sub GetVersionTable {
     return if $::VersionTableLoaded;
-    my $mtime = ModTime("$var_lib/data/versioncache");
-    if (!defined $mtime || $mtime eq "" || !-r "$var_lib/data/versioncache") {
+    my $mtime = ModTime("data/versioncache");
+    if (!defined $mtime || $mtime eq "" || !-r "data/versioncache") {
         $mtime = 0;
     }
     if (time() - $mtime > 3600) {
@@ -633,13 +625,13 @@ sub GetVersionTable {
         Token::CleanTokenTable();
         GenerateVersionTable();
     }
-    require "$var_lib/data/versioncache";
+    require 'data/versioncache';
     if (!defined %::versions) {
         GenerateVersionTable();
-        do "$var_lib/data/versioncache";
+        do 'data/versioncache';
 
         if (!defined %::versions) {
-            die "Can't generate file $var_lib/data/versioncache";
+            die "Can't generate file data/versioncache";
         }
     }
     $::VersionTableLoaded = 1;
@@ -1447,13 +1439,13 @@ sub Param ($) {
     }
 
     # Um, maybe we haven't sourced in the params at all yet.
-    if (stat("$var_lib/data/params")) {
+    if (stat("data/params")) {
         # Write down and restore the version # here.  That way, we get around
         # anyone who maliciously tries to tweak the version number by editing
         # the params file.  Not to mention that in 2.0, there was a bug that
         # wrote the version number out to the params file...
         my $v = $::param{'version'};
-        require "$var_lib/data/params";
+        require "data/params";
         $::param{'version'} = $v;
     }
     if (defined $::param{$value}) {
@@ -1549,7 +1541,7 @@ use Template;
 $::template ||= Template->new(
   {
     # Colon-separated list of directories containing templates.
-    INCLUDE_PATH => "$custom_template_dir/en/custom:$template_dir/en/default" ,
+    INCLUDE_PATH => "template/en/custom:template/en/default" ,
 
     # Remove white-space before template directives (PRE_CHOMP) and at the
     # beginning and end of templates and template blocks (TRIM) for better 
@@ -1558,7 +1550,7 @@ $::template ||= Template->new(
     PRE_CHOMP => 1 ,
     TRIM => 1 , 
 
-    COMPILE_DIR => "$cache_dir/template",
+    COMPILE_DIR => 'data/',
 
     # Functions for processing text within templates in various ways.
     # IMPORTANT!  When adding a filter here that does not override a
